=======
History
=======

2020.12.4 (4 December 2020)
---------------------------

* First working release on PyPI.

2021.2.2 (2 February 2021)
--------------------------

* Internal Release

  - Compatible with the enhance version of MolSystem classes.

2021.2.10 (10 February 2021)
----------------------------

* Updated the README file to give a better description.
* Updated the short description in setup.py to work with the new installer.
* Added keywords for better searchability.
